@@ -1,7 +1,9 @@
 package Pod::From::Acme::CPANModules;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-04-30'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DIST = 'Pod-From-Acme-CPANModules'; # DIST
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,7 +21,18 @@ sub _markdown_to_pod {
 
 $SPEC{gen_pod_from_acme_cpanmodules} = {
     v => 1.1,
-    summary => 'Create "INCLUDED MODULES" POD sections from $LIST',
+    summary => 'Generate POD from an Acme::CPANModules::* module',
+    description => <<'_',
+
+Currently what this routine does:
+
+* Fill the Description section from the CPANModules' list description
+
+* Add an Included Modules section, containing the CPANModules' list entries
+
+* Add a Feature Comparison Matrix section, if one or more entries have 'features'
+
+_
     args_rels => {
         req_one => [qw/module author_lists/],
         choose_all => [qw/author_lists module_lists/],
@@ -93,7 +106,7 @@ sub gen_pod_from_acme_cpanmodules {
 }
 
 1;
-# ABSTRACT: Create "INCLUDED MODULES" POD sections from $LIST
+# ABSTRACT: Generate POD from an Acme::CPANModules::* module
 
 __END__
 
@@ -103,11 +116,11 @@ __END__
 
 =head1 NAME
 
-Pod::From::Acme::CPANModules - Create "INCLUDED MODULES" POD sections from $LIST
+Pod::From::Acme::CPANModules - Generate POD from an Acme::CPANModules::* module
 
 =head1 VERSION
 
-This document describes version 0.003 of Pod::From::Acme::CPANModules (from Perl distribution Pod-From-Acme-CPANModules), released on 2020-04-30.
+This document describes version 0.004 of Pod::From::Acme::CPANModules (from Perl distribution Pod-From-Acme-CPANModules), released on 2020-04-30.
 
 =head1 SYNOPSIS
 
@@ -124,7 +137,19 @@ Usage:
 
  gen_pod_from_acme_cpanmodules(%args) -> any
 
-Create "INCLUDED MODULES" POD sections from $LIST.
+Generate POD from an Acme::CPANModules::* module.
+
+Currently what this routine does:
+
+=over
+
+=item * Fill the Description section from the CPANModules' list description
+
+=item * Add an Included Modules section, containing the CPANModules' list entries
+
+=item * Add a Feature Comparison Matrix section, if one or more entries have 'features'
+
+=back
 
 This function is not exported by default, but exportable.
 
